.. include:: ../common.rst



|Time90|

Inheritance, Superclass, Subclass
==================================

In this lesson, you will learn how to use inheritance to create subclasses that extend superclasses.

.. toctree::
   :maxdepth: 3

   topic-9-1-inheritance-day1.rst
   topic-9-1-inheritance-day2.rst
